smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups

# ``smartcard`.`pcsc`.`PCSCReaderGroups`.`pcscinnerreadergroups``

class documentation

`class pcscinnerreadergroups(innerreadergroups):`

View In Hierarchy

Smartcard PCSC readers groups inner class.

The PCSCReaderGroups singleton manages the creation of the unique instance of this class.

Method | `__init__` | Constructor.
Method | `addreadergroup` | Add a reader group
Method | `getreadergroups` | Returns the list of smartcard reader groups.
Method | `removereadergroup` | Remove a reader group
Instance Variable | `unremovablegroups` | Undocumented

Inherited from `innerreadergroups`:

Method | `__iter__` | Undocumented
Method | `__onadditem__` | Called when a reader group is added.
Method | `__onremoveitem__` | Called when a reader group is added.
Method | `addreadertogroup` | Add a reader to a reader group
Method | `next` | Undocumented
Method | `removereaderfromgroup` | Remove a reader from a reader group

Inherited from `ulist` (via `innerreadergroups`):

Method | `__add__` | Undocumented
Method | `__appendother__` | Append other to object.
Method | `__iadd__` | Undocumented
Method | `__radd__` | Undocumented
Method | `append` | Undocumented
Method | `insert` | Undocumented
Method | `pop` | Undocumented
Method | `remove` | Undocumented
Method | `__remove_duplicates` | Remove from other items already in list.

def __init__(self, initlist=None):
overrides `smartcard.reader.ReaderGroups.innerreadergroups.__init__`

Constructor.

def addreadergroup(self, newgroup):
overrides `smartcard.reader.ReaderGroups.innerreadergroups.addreadergroup`

Add a reader group

def getreadergroups(self):
overrides `smartcard.reader.ReaderGroups.innerreadergroups.getreadergroups`

Returns the list of smartcard reader groups.

def removereadergroup(self, group):
overrides `smartcard.reader.ReaderGroups.innerreadergroups.removereadergroup`

Remove a reader group

unremovablegroups: `list[str]` =
overrides `smartcard.reader.ReaderGroups.innerreadergroups.unremovablegroups`

Undocumented